GatherOS
===============================

version number: 0.0.1
author: John Torakis

Overview
--------

A suite for gathering and presenting OS related information

Installation / Usage
--------------------

To install use pip:

    $ pip install gatheros


Or clone the repo:

    $ git clone https://github.com/operatorequals/gatheros.git
    $ python setup.py install
    
Contributing
------------

TBD

Example
-------

TBD